win32 tweaks: disable XSLOCKS in perl.c, correct typo, search
Douglas Lankshear [Tue, 21 Jul 1998 11:08:00 +0000 (04:08 -0700)]
the registry for anything that begins with "PERL", not "PERL5"
Message-Id: <000601bdb4d2$7ee74720$a32fa8c0@tau.Active>

p4raw-id: //depot/perl@1629

perl.c
win32/perlhost.h
win32/win32.c

diff --git a/perl.c b/perl.c
index df306dc..27936cf 100644 (file)
--- a/perl.c
+++ b/perl.c
@@ -2957,6 +2957,9 @@ my_exit_jump(void)
     JMPENV_JUMP(2);
 }
 
+#ifdef PERL_OBJECT
+#define NO_XSLOCKS
+#endif  /* PERL_OBJECT */
 
 #include "XSUB.h"
 
index 729dd57..e2d8ca7 100644 (file)
@@ -661,7 +661,7 @@ public:
     };
     virtual int GetBufsiz(PerlIO* pf, int &err)
     {
-#ifdef FILE_bufsize
+#ifdef FILE_bufsiz
        FILE *f = (FILE*)pf;
        return FILE_bufsiz(f);
 #else
index dd9fa69..970fc3f 100644 (file)
@@ -942,13 +942,13 @@ win32_getenv(const char *name)
     }
     else
     {
/* allow any environment variables that begin with 'PERL5'
           to be stored in the registry
        */
        if(curitem != NULL)
            *curitem = '\0';
 
-       if (strncmp(name, "PERL5", 5) == 0) {
+       if (strncmp(name, "PERL", 4) == 0) {
            if (curitem != NULL) {
                Safefree(curitem);
                curitem = NULL;
@@ -942,13 +942,13 @@ win32_getenv(const char *name)
     else
     {
-       /* allow any environment variables that begin with 'PERL5'
+       /* allow any environment variables that begin with 'PERL'
           to be stored in the registry
        */